ChangeLog for ap_scanner
====================================================================================
v0.1.2 | 10/02/23 | short description
- Fix pyproject.toml to include changelog and supporting modules
- Update README.md to reflect current output
- Remove scapy dependency (not used)

====================================================================================

v0.1.1 | 10/02/23 | Restructure / Cleanup
- no functionality changes
- repackage code modules
- documentation strings and logging
- *** THIS VERSION IS BROKEN - do not use ***

====================================================================================

v0.1.0 | 10/01/23 | Initial release  
- Support for Windows/Linux
- Tested on 
    - Windows 10/11
    - Ubuntu Ubuntu 22.04.3 LTS
    - RaspPi OS - Debian GNU/Linux 11 (bullseye) / Raspbian GNU/Linux 10 (buster)

